<?php

class ControllerExtensionShippingDhlparcel extends Controller {
    private $error = [];

    public function index() {
        $this->load->language('extension/shipping/dhlparcel');

        $this->document->setTitle($this->language->get('heading_title'));

        $this->load->model('setting/setting');

        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
            $this->model_setting_setting->editSetting('shipping_dhlparcel', $this->request->post);

            $this->session->data['success'] = $this->language->get('text_success');

            $this->response->redirect($this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=shipping', TRUE));
        }


        $data = [
            'breadcrumbs' => [
                [
                    'text' => $this->language->get('text_home'),
                    'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], TRUE),
                ],
                [
                    'text' => $this->language->get('text_extension'),
                    'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=shipping', TRUE),
                ],
                [
                    'text' => $this->language->get('heading_title'),
                    'href' => $this->url->link('extension/shipping/dhlparcel', 'user_token=' . $this->session->data['user_token'], TRUE),
                ],
            ],
        ];

        if (isset($this->error['warning'])) {
            $data['error_warning'] = $this->error['warning'];
        } else {
            $data['error_warning'] = '';
        }

        if (isset($this->request->post['shipping_dhlparcel_status'])) {
            $data['shipping_dhlparcel_status'] = $this->request->post['shipping_dhlparcel_status'];
        } else {
            $data['shipping_dhlparcel_status'] = $this->config->get('shipping_dhlparcel_status');
        }

        if (isset($this->request->post['shipping_dhlparcel_url'])) {
            $data['shipping_dhlparcel_url'] = $this->request->post['shipping_dhlparcel_url'];
        } else {
            $data['shipping_dhlparcel_url'] = $this->config->get('shipping_dhlparcel_url');
        }

        if (isset($this->request->post['shipping_dhlparcel_order_status_id'])) {
            $data['shipping_dhlparcel_order_status_id'] = $this->request->post['shipping_dhlparcel_order_status_id'];
        } else {
            $data['shipping_dhlparcel_order_status_id'] = $this->config->get('shipping_dhlparcel_order_status_id');
        }

        $this->load->model('localisation/order_status');
        $data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();

        $data['action'] = $this->url->link('extension/shipping/dhlparcel', 'user_token=' . $this->session->data['user_token'], TRUE);
        $data['cancel'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=shipping', TRUE);

        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('extension/shipping/dhlparcel', $data));
    }

    protected function validate() {
        if (!$this->user->hasPermission('modify', 'extension/shipping/dhlparcel')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }

        return !$this->error;
    }

    public function install() {

        $this->load->model('setting/setting');
        $this->load->model('setting/event');
        $this->load->model('localisation/order_status');
        $id = 0;
        foreach ($this->model_localisation_order_status->getOrderStatuses() as $status) {
            if ($status['name'] == 'Pending') {
                $id = $status['order_status_id'];
                break;
            }
        }

        $this->model_setting_setting->editSetting('shipping_dhlparcel', ['shipping_dhlparcel_status' => 1, 'shipping_dhlparcel_order_status_id' => $id]);

        $this->model_setting_event->addEvent('shipping_dhlparcel_webhook', 'catalog/model/checkout/order/addOrderHistory/before', 'extension/shipping/dhlparcel/webhook');
    }

    public function uninstall() {
        $this->load->model('setting/event');
        $this->model_setting_event->deleteEventByCode('shipping_dhlparcel_webhook');
    }
}
